aboutsummaryrefslogtreecommitdiff
path: root/gdb/ser-tcp.c
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/ser-tcp.c')
-rw-r--r--gdb/ser-tcp.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gdb/ser-tcp.c b/gdb/ser-tcp.c
index 21d8476..de8c428 100644
--- a/gdb/ser-tcp.c
+++ b/gdb/ser-tcp.c
@@ -48,7 +48,7 @@ void _initialize_ser_tcp (void);
/* seconds to wait for connect */
#define TIMEOUT 15
/* how many times per second to poll ui_loop_hook */
#define POLL_INTERVAL 2
/* Open a tcp socket */
@@ -132,9 +132,9 @@ net_open (struct serial *scb, const char *name)
/* While we wait for the connect to complete
poll the UI so it can update or the user can
interrupt. */
- if (ui_loop_hook)
+ if (deprecated_ui_loop_hook)
{
- if (ui_loop_hook (0))
+ if (deprecated_ui_loop_hook (0))
{
errno = EINTR;
net_close (scb);
@@ -48,7 +48,7 @@ void _initialize_ser_tcp (void);
/* seconds to wait for connect */
#define TIMEOUT 15
-/* how many times per second to poll ui_loop_hook */
+/* how many times per second to poll deprecated_ui_loop_hook */
#define POLL_INTERVAL 2
/* Open a tcp socket */